==> 1.0.119+1.tar.gz: lib/components/UikImage.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikImageProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

class UikImage extends UikWidget {
  WidgetType _widgetType;
  UikImageProps _uikImageProps;
  UikImage(this._widgetType, this._uikImageProps)
      : super(_widgetType, _uikImageProps);

  @override
  _UikImageState createState() => _UikImageState(_uikImageProps);
}

class _UikImageState extends State<UikImage> {
  UikImageProps _uikImageProps;
  _UikImageState(this._uikImageProps);

  @override
  Widget build(BuildContext context) {
    final imageAction = this._uikImageProps.action;
    return InkWell(
      onTap: imageAction != null
          ? () async {
              await executeUikWidgetAction(imageAction);
            }
          : null,
      child: CachedNetworkImage(
        imageUrl: _uikImageProps.url,
        imageBuilder: (context, imageProvider) => Container(
          width: _uikImageProps.width,
          height: _uikImageProps.height,
          margin: EdgeInsets.only(
            top: _uikImageProps.topMargin,
            left: _uikImageProps.leftMargin,
            right: _uikImageProps.rightMargin,
            bottom: _uikImageProps.bottomMargin,
          ),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.only(
              topLeft: Radius.circular(_uikImageProps.topLeftRadius),
              topRight: Radius.circular(_uikImageProps.topRightRadius),
              bottomLeft: Radius.circular(_uikImageProps.bottomLeftRadius),
              bottomRight: Radius.circular(_uikImageProps.bottomRightRadius),
            ),
            image: DecorationImage(
              image: imageProvider,
              fit: BoxFit.fill,
            ),
          ),
        ),
        // placeholder: (context, url) => CircularProgressIndicator(),
        errorWidget: (context, url, error) => Icon(Icons.error),
      ),
    );
  }
}

==> 1.0.128+1.tar.gz: lib/components/UikImage.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikImageProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

class UikImage extends UikWidget {
  WidgetType _widgetType;
  UikImageProps _uikImageProps;
  UikImage(this._widgetType, this._uikImageProps)
      : super(_widgetType, _uikImageProps);

  @override
  _UikImageState createState() => _UikImageState(_uikImageProps);
}

class _UikImageState extends State<UikImage> {
  UikImageProps _uikImageProps;
  _UikImageState(this._uikImageProps);

  @override
  Widget build(BuildContext context) {
    final imageAction = this._uikImageProps.action;
    return InkWell(
      onTap: imageAction != null
          ? () async {
              await executeUikWidgetAction(imageAction,context);
            }
          : null,
      child: CachedNetworkImage(
        imageUrl: _uikImageProps.url,
        imageBuilder: (context, imageProvider) => Container(
          width: _uikImageProps.width,
          height: _uikImageProps.height,
          margin: EdgeInsets.only(
            top: _uikImageProps.topMargin,
            left: _uikImageProps.leftMargin,
            right: _uikImageProps.rightMargin,
            bottom: _uikImageProps.bottomMargin,
          ),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.only(
              topLeft: Radius.circular(_uikImageProps.topLeftRadius),
              topRight: Radius.circular(_uikImageProps.topRightRadius),
              bottomLeft: Radius.circular(_uikImageProps.bottomLeftRadius),
              bottomRight: Radius.circular(_uikImageProps.bottomRightRadius),
            ),
            image: DecorationImage(
              image: imageProvider,
              fit: BoxFit.fill,
            ),
          ),
        ),
        // placeholder: (context, url) => CircularProgressIndicator(),
        errorWidget: (context, url, error) => Icon(Icons.error),
      ),
    );
  }
}
